<div class="home-header" markdown="1">

# SDKite

<div class="description">Simple framework for building SDKs and API clients</div>

</div>

<!-- FIXME add introduction -->

## Installation

Install _SDKite_ with pip:

    :::sh
    $ python -m pip install sdkite

## Python version support

As a general rule, all Python versions that are both [released and still officially
supported][python-versions] are supported by `sdkite` and tested against.

If you have other use cases or find issues with some Python versions, feel free to
[open a ticket](https://github.com/Rogdham/sdkite/issues/new)!

[python-versions]: https://devguide.python.org/versions/#supported-versions

## Status of the project

_SDKite_ is currently in **pre-alpha**: the API may change in future releases. Changes
are well detailed in the [changelog], and the version numbering follow [semver].

[changelog]: https://github.com/Rogdham/sdkite/blob/master/CHANGELOG.md
[semver]: https://semver.org/

!!! Note

    This documentation is also a work-in-progress.
